@@ -6,6 +6,7 @@
 #' @param x data.frame of intenticy of traffic by hours (rows) and weekdays
 #' (columns)
 #' @param file emission file name
+#' @param adjust numer of hours to advance (positive value) or delay (negative value)
 #' @param verbose display additional information
 #'
 #' @format a numeric vector
@@ -52,7 +53,7 @@
 #' axis(1, at = 0.5 + c(0, 6, 12, 18, 24),
 #'     labels = c("00:00","06:00","12:00","18:00", "00:00"))
 #'}
-wrf_profile <- function(x,file,verbose = T){
+wrf_profile <- function(x,file,adjust = 0 ,verbose = T){
   x       <- as.data.frame(x)
   times   <- wrf_get(file,"Times")
   profile <- vector(mode = "numeric",length = length(times))
@@ -66,9 +67,22 @@ wrf_profile <- function(x,file,verbose = T){
     dia      <- weekdays(as.Date(data[1]))
     profile[i] <- as.numeric(x[hora+1,s+1])
     if(verbose){
-      print(unlist(strsplit(times[i],"_")))
-      print(paste0("Weekday: ",dia," Traffic Intensity: ",profile[i]))
+      cat(unlist(strsplit(times[i],"_")))
+      cat(paste0("\nWeekday: ",dia," - Activity intensity: ",profile[i],"\n")) #
     }
   }
-  return(profile)
+  if(adjust == 0)
+    return(profile)
+  else{                             # nocov start
+    if(adjust < 0){
+      cat(paste0('delaying the profile by ',-adjust,' hour\n'))
+      profile <- c( profile[(length(profile)+adjust+1):length(profile)] ,
+                    profile[1:(length(profile)+adjust)] )
+    }
+    if(adjust > 0){
+      cat(paste0('advancing the profile by ',adjust,' hour\n'))
+      profile <- c( profile[(adjust+1):length(profile)] , profile[1:adjust] )
+    }
+    return(profile)                 # nocov end
+  }
 }
